"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const addMenuItemToMenu_1 = require("./addMenuItemToMenu");
const chai_1 = require("chai");
describe("addMenuItemToMenu", () => {
    const route = '/route';
    const MENU_INPUT = `
    <Menu>
      <Menu.DashboardItem />
      <Menu.ResourceItem name="OwnerDTO" />
      <Menu.Item  to="/OldComponent" primaryText="OldComponent" />
    </Menu>
  `;
    it("should add menu item to menu, if item not exist", function () {
        const componentName = "NewComponent";
        const res = (0, addMenuItemToMenu_1.addMenuItemToMenu)(MENU_INPUT, route, componentName);
        (0, chai_1.expect)(res).to.contain(`<Menu.Item  to="/route" primaryText="routes.NewComponent" leftIcon={<WebAsset />} />`);
    });
    it("should add menu item to empty menu", function () {
        const componentName = "NewComponent";
        const res = (0, addMenuItemToMenu_1.addMenuItemToMenu)(`<Menu></Menu>`, route, componentName);
        (0, chai_1.expect)(res).to.contain(`<Menu.Item  to="/route" primaryText="routes.NewComponent" leftIcon={<WebAsset />} />`);
    });
    it("should do nothing if menu item already in menu", function () {
        const componentName = "OldComponent";
        const res = (0, addMenuItemToMenu_1.addMenuItemToMenu)(MENU_INPUT, route, componentName);
        (0, chai_1.expect)(res).to.eq(MENU_INPUT);
    });
    it("should fail for incorrect input", function () {
        const componentName = "NewComponent";
        (0, chai_1.expect)(addMenuItemToMenu_1.addMenuItemToMenu.bind(undefined, `Not jsx`, componentName)).to.throw();
        const emptyJsx = '';
        (0, chai_1.expect)(addMenuItemToMenu_1.addMenuItemToMenu.bind(undefined, emptyJsx, componentName)).to.throw();
    });
    it("should fail if Menu tag not found", function () {
        const componentName = "NewComponent";
        (0, chai_1.expect)(addMenuItemToMenu_1.addMenuItemToMenu.bind(undefined, `<NotMenuTag></NotMenuTag>`, componentName))
            .to.throw();
    });
});
//# sourceMappingURL=addMenuItemToMenu.test.js.map