"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.addResourceToMenu = void 0;
const jscodeshift_1 = __importDefault(require("jscodeshift"));
const getMenuTagChildren_1 = require("./getMenuTagChildren");
const toSource_1 = require("../jsCodeShift/toSource");
/**
 * Add resource to menu. If line with such resource already exist - do nothing.
 * Example of added line `<Menu.ResourceItem name="OwnerDTO" />`;
 *
 * @param menuInput jsx menu as test
 * @param resourceName name of resource to be added in menu
 */
function addResourceToMenu(menuInput, resourceName) {
    const tsxParser = jscodeshift_1.default.withParser("tsx");
    const appMenuAST = tsxParser(menuInput);
    const children = (0, getMenuTagChildren_1.getMenuTagChildren)(appMenuAST);
    // check, if such resource item already exist in menu
    const isItemAlreadyExist = children
        .filter(el => el.type === jscodeshift_1.default.JSXElement.toString())
        .some(el => {
        const openingEl = el.openingElement;
        const openingElName = openingEl?.name;
        // looking for item like `<Menu.ResourceItem name="OwnerDTO" />`, where OwnerDTO is resourceName
        return openingElName?.object?.name === "Menu" &&
            openingElName?.property?.name === "ResourceItem" &&
            openingEl?.attributes?.some((attr) => attr.name.name === "name" && attr.value.value === resourceName);
    });
    if (!isItemAlreadyExist) {
        const resourceTag = `<Menu.ResourceItem name="${resourceName}" />`;
        children?.push(jscodeshift_1.default.stringLiteral(resourceTag));
        console.log(`addResourceToMenu: resource item added to menu\n ${resourceTag}`);
    }
    else {
        console.log(`addResourceToMenu: skip adding resource item to menu, item ${resourceName} already exist`);
    }
    return (0, toSource_1.toSource)(appMenuAST);
}
exports.addResourceToMenu = addResourceToMenu;
//# sourceMappingURL=addResourceToMenu.js.map